# Changelog

### [0.1.0](https://github.com/starsoi/tree/v0.1.0) (2021-05-24)

👏 First release 👏

#### Features

* Create execution trace programmatically
* Find event chains using event pattern
* Export trace together with event chains to Chrome trace JSON
